@@ -1,23 +1,10 @@
 /*
- *   Copyright 2007 Aaron Seigo <aseigo@kde.org>
- *   Copyright 2007 Matt Broadstone <mbroadst@gmail.com>
- *   Copyright 2012 Marco MArtin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2007 Matt Broadstone <mbroadst@gmail.com>
+    SPDX-FileCopyrightText: 2012 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PLASMA_CORONA_H
 #define PLASMA_CORONA_H
@@ -30,7 +17,6 @@ class QAction;
 
 namespace Plasma
 {
-
 class CoronaPrivate;
 
 /**
@@ -42,6 +28,7 @@ class PLASMA_EXPORT Corona : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(bool isStartupCompleted READ isStartupCompleted NOTIFY startupCompleted)
+    Q_PROPERTY(bool editMode READ isEditMode WRITE setEditMode NOTIFY editModeChanged)
     Q_PROPERTY(Package package READ package NOTIFY packageChanged)
     Q_PROPERTY(KPackage::Package kPackage READ kPackage NOTIFY kPackageChanged)
 
@@ -49,25 +36,29 @@ public:
     explicit Corona(QObject *parent = nullptr);
     ~Corona();
 
-#ifndef PLASMA_NO_DEPRECATED
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 6)
     /**
      * Accessor for the associated Package object if any.
      * A Corona package defines how Containments are laid out in a View,
      * ToolBoxes, default layout, error messages
-     * and in genelal all the furniture specific of a particular
+     * and in general all the furniture specific of a particular
      * device form factor.
      *
-     * @deprecated use kPackage instead
      * @return the Package object, or an invalid one if none
      * @since 5.0
+     * @deprecated Since 5.6, use kPackage instead
      **/
-    PLASMA_DEPRECATED Plasma::Package package() const;
+    PLASMA_DEPRECATED_VERSION(5, 6, "Use Corona::kPackage()")
+    Plasma::Package package() const;
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 6)
     /**
      * Setting the package name
-     * @deprecated use setKPackage instead
+     * @deprecated Since 5.6, use setKPackage instead
      */
-    PLASMA_DEPRECATED void setPackage(const Plasma::Package &package);
+    PLASMA_DEPRECATED_VERSION(5, 6, "Use Corona::setKPackage(const KPackage::Package &)")
+    void setPackage(const Plasma::Package &package);
 #endif
 
     /**
@@ -121,13 +112,34 @@ public:
      */
     Containment *createContainment(const QString &name, const QVariantList &args = QVariantList());
 
+    /**
+     * Returns the Containment for a given physical screen and desktop, creating one
+     * if none exists
+     *
+     * @param screen number of the physical screen to locate
+     * @param activity the activity id of the containment we want,
+     *                 and empty string if the activity is not important
+     * @param defaultPluginIfNonExistent the plugin to load by default; "null" won't
+     * create it and "default" creates the default plugin
+     * @param defaultArgs optional arguments to pass in when creating a Containment if needed
+     * @since 5.45
+     */
+    Containment *
+    containmentForScreen(int screen, const QString &activity, const QString &defaultPluginIfNonExistent, const QVariantList &defaultArgs = QVariantList());
+
+    // TODO KF6: add activity here, can't be done now as the overload would get confused
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 46)
     /**
      * Returns the Containment, if any, for a given physical screen
      *
      * @param screen number of the physical screen to locate
+     * @deprecated Since 5.46, use containmentForScreen(int, const QString &, const QString &, const QVariantList &)
      */
+    PLASMA_DEPRECATED_VERSION(5, 46, "Use Corona::containmentForScreen(int, const QString &, const QString &, const QVariantList &)")
     Containment *containmentForScreen(int screen) const;
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 46)
     /**
      * Returns the Containment for a given physical screen and desktop, creating one
      * if none exists
@@ -136,10 +148,27 @@ public:
      * @param defaultPluginIfNonExistent the plugin to load by default; "null" is an empty
      * Containment and "default" creates the default plugin
      * @param defaultArgs optional arguments to pass in when creating a Containment if needed
+     * @deprecated Since 5.46, use containmentForScreen(int, const QString &, const QString &, const QVariantList &)
      */
-    Containment *containmentForScreen(int screen,
-                                      const QString &defaultPluginIfNonExistent,
-                                      const QVariantList &defaultArgs = QVariantList());
+    PLASMA_DEPRECATED_VERSION(5, 46, "Use Corona::containmentForScreen(int, const QString &, const QString &, const QVariantList &)")
+    Containment *containmentForScreen(int screen, const QString &defaultPluginIfNonExistent, const QVariantList &defaultArgs = QVariantList());
+#endif
+
+    /**
+     * Returns all containments which match a particular activity, for any screen
+     * @param activity the activity id we want
+     * @returns the list of matching containments if any, empty if activity is an empty string
+     * @since 5.45
+     */
+    QList<Containment *> containmentsForActivity(const QString &activity);
+
+    /**
+     * Returns all containments which match a particular screen, for any activity
+     * @param screen the screen number we want
+     * @returns the list of matching containments if any, empty if screen is < 0
+     * @since 5.45
+     */
+    QList<Containment *> containmentsForScreen(int screen);
 
     /**
      * Returns the number of screens available to plasma.
@@ -188,7 +217,7 @@ public:
     QList<Plasma::Types::Location> freeEdges(int screen) const;
 
     /**
-     * The actions assocated with this Corona
+     * The actions associated with this Corona
      */
     KActionCollection *actions() const;
 
@@ -223,6 +252,21 @@ public:
      */
     Types::ImmutabilityType immutability() const;
 
+    /**
+     * Set the Corona globally into "edit mode"
+     * Only when the corona is of mutable type can be set of edit mode.
+     * This indicates the UI to make easy for the user to manipulate applets.
+     * @param edit
+     * @since 5.63
+     */
+    void setEditMode(bool edit);
+
+    /**
+     * @returns true if the corona is in edit mode
+     * @since 5.63
+     */
+    bool isEditMode() const;
+
 public Q_SLOTS:
     /**
      * Load applet layout from a config file. The results will be added to the
@@ -324,15 +368,23 @@ Q_SIGNALS:
      */
     void screenAdded(int id);
 
-#ifndef PLASMA_NO_DEPRECATED
+    /**
+     * emitted when the editMode state changes
+     * @see isEditMode()
+     * @since 5.63
+     */
+    void editModeChanged(bool edit);
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 6)
     /**
      * Emitted when the package for this corona has been changed.
      * Shells must support changing the shell package on the fly (for instance due to device form factor changing)
      *
-     * @deprecated use kPackageChanged instead
      * @param package the new package that defines the Corona furniture and behavior
+     * @deprecated Since 5.6, use kPackageChanged instead
      */
-    PLASMA_DEPRECATED void packageChanged(const Plasma::Package &package);
+    PLASMA_DEPRECATED_VERSION(5, 6, "Use Corona::kPackageChanged(const KPackage::Package &)")
+    void packageChanged(const Plasma::Package &package);
 #endif
 
     /**
@@ -357,10 +409,10 @@ protected:
     /**
      * Loads a containment with delayed initialization, primarily useful
      * for implementations of loadDefaultLayout. The caller is responsible
-     * for all initializating, saving and notification of a new containment.
+     * for all initialization, saving and notification of a new containment.
      *
      * @param name the plugin name for the containment, as given by
-     *        KPluginInfo::pluginName(). If an empty string is passed in, the defalt
+     *        KPluginInfo::pluginName(). If an empty string is passed in, the default
      *        containment plugin will be used (usually DesktopContainment). If the
      *        string literal "null" is passed in, then no plugin will be loaded and
      *        a simple Containment object will be created instead.
@@ -372,8 +424,8 @@ protected:
      * or successfully loaded.
      * @see addContainment
      **/
-    Containment *createContainmentDelayed(const QString &name,
-                                          const QVariantList &args = QVariantList());
+    Containment *createContainmentDelayed(const QString &name, const QVariantList &args = QVariantList());
+
 private:
     CoronaPrivate *const d;
 
@@ -389,4 +441,3 @@ private:
 } // namespace Plasma
 
 #endif
-
